@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::App::Command::old;
 {
-  $App::Magpie::App::Command::old::VERSION = '2.000';
+  $App::Magpie::App::Command::old::VERSION = '2.001';
 }
 # ABSTRACT: report installed perl modules with new version available 
 
@@ -54,9 +54,11 @@ sub execute {
         }
 
         my $label = $set->name;
-        say "** $label packages: " . $set->nb_modules;
+        say "** $label packages: " . $set->nb_modules . " modules";
         say '';
 
+        my %seen;
+        MODULE:
         foreach my $module ( sort $set->all_modules ) {
             my @pkgs = $module->packages;
             given ( scalar(@pkgs) ) {
@@ -69,6 +71,7 @@ sub execute {
                 }
                 when (1) {
                     my $pkg = shift @pkgs;
+                    next MODULE if $seen{ $pkg->name }++;
                     say encode( 'utf-8',
                         $pad->left ( $module->name, 40 )   .
                         $pad->right( $module->oldver, 14 ) .
@@ -114,7 +117,7 @@ App::Magpie::App::Command::old - report installed perl modules with new version
 
 =head1 VERSION
 
-version 2.000
+version 2.001
 
 =head1 SYNOPSIS
 
